@@ -19,7 +19,8 @@ set -euo pipefail
 if ! command -v go-md2man >/dev/null; then
     echo "Installing go-md2man"
     HACK_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd -P)"
-    go install -C ${HACK_DIR}/tools github.com/cpuguy83/go-md2man
+    MD2MAN=github.com/cpuguy83/go-md2man/v2
+    go install -C "${HACK_DIR}/tools" "$MD2MAN@$(go list -m -f \{\{.Version\}\} $MD2MAN)"
 fi
 
 go-md2man -in docs/crictl.md -out docs/crictl.1
